@@ -277,6 +277,13 @@ def display(*objs, **kwargs):
         from IPython.display import display
 
     """
+    from IPython.core.interactiveshell import InteractiveShell
+    
+    if not InteractiveShell.initialized():
+        # Directly print objects.
+        print(*objs)
+        return
+    
     raw = kwargs.pop('raw', False)
     include = kwargs.pop('include', None)
     exclude = kwargs.pop('exclude', None)
@@ -294,8 +301,6 @@ def display(*objs, **kwargs):
     if transient:
         kwargs['transient'] = transient
 
-    from IPython.core.interactiveshell import InteractiveShell
-
     if not raw:
         format = InteractiveShell.instance().display_formatter.format
 
@@ -775,6 +780,23 @@ class ProgressBar(DisplayObject):
         self._progress = value
         self.update()
 
+    def __iter__(self):
+        self.display()
+        self._progress = -1 # First iteration is 0
+        return self
+
+    def __next__(self):
+        """Returns current value and increments display by one."""
+        self.progress += 1
+        if self.progress < self.total:
+            return self.progress
+        else:
+            raise StopIteration()
+            
+    def next(self):
+        """Python 2 compatibility"""
+        return self.__next__() 
+
 class JSON(DisplayObject):
     """JSON expects a JSON-able dict or list
     
@@ -990,7 +1012,7 @@ class Image(DisplayObject):
             if ext is not None:
                 if ext == u'jpg' or ext == u'jpeg':
                     format = self._FMT_JPEG
-                if ext == u'png':
+                elif ext == u'png':
                     format = self._FMT_PNG
                 else:
                     format = ext.lower()
