@@ -1,4 +1,4 @@
-"""IPython terminal interface using prompt_toolkit"""
+"""IPython terminal interface using prompt_toolkit1"""
 from __future__ import print_function
 
 import os
@@ -13,17 +13,17 @@ from IPython.utils.terminal import toggle_set_term_title, set_term_title
 from IPython.utils.process import abbrev_cwd
 from traitlets import Bool, Unicode, Dict, Integer, observe, Instance, Type, default, Enum, Union
 
-from prompt_toolkit.document import Document
-from prompt_toolkit.enums import DEFAULT_BUFFER, EditingMode
-from prompt_toolkit.filters import (HasFocus, Condition, IsDone)
-from prompt_toolkit.history import InMemoryHistory
-from prompt_toolkit.shortcuts import create_prompt_application, create_eventloop, create_prompt_layout, create_output
-from prompt_toolkit.interface import CommandLineInterface
-from prompt_toolkit.key_binding.manager import KeyBindingManager
-from prompt_toolkit.layout.processors import ConditionalProcessor, HighlightMatchingBracketProcessor
-from prompt_toolkit.styles import PygmentsStyle, DynamicStyle
+from prompt_toolkit1.document import Document
+from prompt_toolkit1.enums import DEFAULT_BUFFER, EditingMode
+from prompt_toolkit1.filters import (HasFocus, Condition, IsDone)
+from prompt_toolkit1.history import InMemoryHistory
+from prompt_toolkit1.shortcuts import create_prompt_application, create_eventloop, create_prompt_layout, create_output
+from prompt_toolkit1.interface import CommandLineInterface
+from prompt_toolkit1.key_binding.manager import KeyBindingManager
+from prompt_toolkit1.layout.processors import ConditionalProcessor, HighlightMatchingBracketProcessor
+from prompt_toolkit1.styles import PygmentsStyle, DynamicStyle
 
-from pygments.styles import get_style_by_name, get_all_styles
+from pygments.styles import get_style_by_name
 from pygments.style import Style
 from pygments.token import Token
 
@@ -104,7 +104,7 @@ class TerminalInteractiveShell(InteractiveShell):
     _pt_app = None
 
     simple_prompt = Bool(_use_simple_prompt,
-        help="""Use `raw_input` for the REPL, without completion, multiline input, and prompt colors.
+        help="""Use `raw_input` for the REPL, without completion and prompt colors.
 
             Useful when controlling IPython as a subprocess, and piping STDIN/OUT/ERR. Known usage are:
             IPython own testing machinery, and emacs inferior-shell integration through elpy.
@@ -134,9 +134,11 @@ class TerminalInteractiveShell(InteractiveShell):
         help="Enable mouse support in the prompt"
     ).tag(config=True)
 
+    # We don't load the list of styles for the help string, because loading
+    # Pygments plugins takes time and can cause unexpected errors.
     highlighting_style = Union([Unicode('legacy'), Type(klass=Style)],
         help="""The name or class of a Pygments style to use for syntax
-        highlighting: \n %s""" % ', '.join(get_all_styles())
+        highlighting. To see available styles, run `pygmentize -L styles`."""
     ).tag(config=True)
 
 
@@ -164,7 +166,7 @@ class TerminalInteractiveShell(InteractiveShell):
         help="Set the editor used by IPython (default to $EDITOR/vi/notepad)."
     ).tag(config=True)
 
-    prompts_class = Type(Prompts, help='Class used to generate Prompt token for prompt_toolkit').tag(config=True)
+    prompts_class = Type(Prompts, help='Class used to generate Prompt token for prompt_toolkit1').tag(config=True)
 
     prompts = Instance(Prompts)
 
@@ -186,8 +188,8 @@ class TerminalInteractiveShell(InteractiveShell):
 
     display_completions = Enum(('column', 'multicolumn','readlinelike'),
         help= ( "Options for displaying tab completions, 'column', 'multicolumn', and "
-                "'readlinelike'. These options are for `prompt_toolkit`, see "
-                "`prompt_toolkit` documentation for more information."
+                "'readlinelike'. These options are for `prompt_toolkit1`, see "
+                "`prompt_toolkit1` documentation for more information."
                 ),
         default_value='multicolumn').tag(config=True)
 
@@ -216,12 +218,19 @@ class TerminalInteractiveShell(InteractiveShell):
         # disable `_ipython_display_`
         self.display_formatter.ipython_display_formatter.enabled = False
 
-    def init_prompt_toolkit_cli(self):
+    def init_prompt_toolkit1_cli(self):
         if self.simple_prompt:
             # Fall back to plain non-interactive output for tests.
             # This is very limited, and only accepts a single line.
             def prompt():
-                return cast_unicode_py2(input('In [%d]: ' % self.execution_count))
+                isp = self.input_splitter
+                prompt_text = "".join(x[1] for x in self.prompts.in_prompt_tokens())
+                prompt_continuation = "".join(x[1] for x in self.prompts.continuation_prompt_tokens())
+                while isp.push_accepts_more():
+                    line = cast_unicode_py2(input(prompt_text))
+                    isp.push(line)
+                    prompt_text = prompt_continuation
+                return isp.source_reset()
             self.prompt_for_code = prompt
             return
 
@@ -243,7 +252,7 @@ class TerminalInteractiveShell(InteractiveShell):
                 last_cell = cell
 
         self._style = self._make_style_from_name_or_cls(self.highlighting_style)
-        style = DynamicStyle(lambda: self._style)
+        self.style = DynamicStyle(lambda: self._style)
 
         editing_mode = getattr(EditingMode, self.editing_mode.upper())
 
@@ -257,7 +266,7 @@ class TerminalInteractiveShell(InteractiveShell):
                             completer=IPythonPTCompleter(shell=self,
                                                     patch_stdout=patch_stdout),
                             enable_history_search=True,
-                            style=style,
+                            style=self.style,
                             mouse_support=self.mouse_support,
                             **self._layout_options()
         )
@@ -429,7 +438,7 @@ class TerminalInteractiveShell(InteractiveShell):
 
     def __init__(self, *args, **kwargs):
         super(TerminalInteractiveShell, self).__init__(*args, **kwargs)
-        self.init_prompt_toolkit_cli()
+        self.init_prompt_toolkit1_cli()
         self.init_term_title()
         self.keep_running = True
 
@@ -451,7 +460,7 @@ class TerminalInteractiveShell(InteractiveShell):
             if hasattr(self.pt_cli, 'pre_run_callables'):
                 self.pt_cli.pre_run_callables.append(set_doc)
             else:
-                # Older version of prompt_toolkit; it's OK to set the document
+                # Older version of prompt_toolkit1; it's OK to set the document
                 # directly here.
                 set_doc()
             self.rl_next_input = None
@@ -489,7 +498,7 @@ class TerminalInteractiveShell(InteractiveShell):
                 print("\n%s escaped interact()\n" % type(e).__name__)
             finally:
                 # An interrupt during the eventloop will mess up the
-                # internal state of the prompt_toolkit library.
+                # internal state of the prompt_toolkit1 library.
                 # Stopping the eventloop fixes this, see
                 # https://github.com/ipython/ipython/pull/9867
                 if hasattr(self, '_eventloop'):
